@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate musical cadence chords
 
-our $VERSION = '0.1203';
+our $VERSION = '0.1300';
 
 use Moo;
 use Music::Chord::Note;
@@ -103,11 +103,15 @@ sub cadence {
     }
     elsif ( $type eq 'evaded' && $self->seven ) {
         my $chord = $self->_generate_chord( $key, $scale, $scale_notes[4], $octave );
-        $chord = $self->_invert_chord( $chord, 3, $octave );
+        $inversion = { 1 => 3 }
+            unless $inversion && $inversion->{1};
+        $chord = $self->_invert_chord( $chord, $inversion->{1}, $octave );
         push @$cadence, $chord;
 
         $chord = $self->_generate_chord( $key, $scale, $scale_notes[0], $octave );
-        $chord = $self->_invert_chord( $chord, 1, $octave );
+        $inversion = { 2 => 1 }
+            unless $inversion && $inversion->{2};
+        $chord = $self->_invert_chord( $chord, $inversion->{2}, $octave );
         push @$cadence, $chord;
     }
     elsif ( $type eq 'plagal' ) {
@@ -245,7 +249,7 @@ Music::Cadence - Generate musical cadence chords
 
 =head1 VERSION
 
-version 0.1203
+version 0.1300
 
 =head1 SYNOPSIS
 
@@ -446,9 +450,8 @@ To B<not> apply an inversion to an inverted imperfect cadence chord,
 either do not include the numbered chord in the hash reference, or
 set its value to C<0> zero.
 
-The B<leading> chord is a number (1-7) for each diatonic scale chord
-to use for the first C<half> cadence chord.  For the key of C<C major>
-this is:
+The B<leading> chord is a number (1-7) for the scale chord to use for
+the first C<half> cadence chord.  For the key of C<C major> this is:
 
   CM: 1
   Dm: 2
@@ -461,7 +464,9 @@ this is:
 If an B<inversion> is defined for the C<half> cadence, the chords are
 inverted as described above for the C<imperfect> cadence.
 
-The B<evaded> cadence applies inversions to seventh chords.
+The B<evaded> cadence applies inversions to seventh chords.  The
+default (with no B<inversion> defined) is to invert the first chord by
+the third inversion and the second by the first inversion.
 
 =head1 SEE ALSO
 
